# cvutilities

Miscellaneous utilities for working with camera data:

* Functions which load camera calibration data from local JSON files

* Wrappers which reshape inputs, feed them through different combinations of various OpenCV functions, and regularize the outputs

* Functions which support basic visualization of image and object points
